
//
// XML storage classes version 1.2
//
// Example2.java
//
// Copyright (c) 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

import de.mfuchs.xmlstorage.XMLDoc;
import de.mfuchs.xmlstorage.XMLIntRef;
import de.mfuchs.xmlstorage.XMLPos;
import de.mfuchs.xmlstorage.XMLStringRef;


/**
 * Example to use XMLStorage for writing and
 * reading XML files containing numbers.
 * 
 * @author martin
 */
public class Example2
{
	/**
	 * Write an example XML file to disk.
	 * @throws Exception
	 */
    @Test public void testWrite() throws Exception
    {
        XMLDoc doc = new XMLDoc();
        XMLPos pos = new XMLPos(doc);

         // Zusammenstellen der XML-Struktur im Dokument 'doc'
        pos.create("PARAMS");
          pos.put("text", "Testgruppe");

          pos.create("COLOR");
            new XMLIntRef(pos, "red").assign(234);
            new XMLIntRef(pos, "green").assign(22);
            new XMLIntRef(pos, "blue").assign(33);
          pos.back(); // </COLOR>

          pos.create("FONT");
            new XMLStringRef(pos, "font-filename").assign("Arial.ttf");
            new XMLIntRef(pos, "size").assign(12);
            pos.back(); // </SIZE>
          pos.back(); // </FONT>
        pos.back(); // </PARAMS>

         // Schreiben der XML-Datei
        doc.writeFile("example2.xml");
    }


    /**
     * Read the example file back again.
     * @throws Exception
     */
    @Test public void testRead() throws Exception
    {
         // Einlesen des XML-Files
        XMLDoc doc = new XMLDoc("example2.xml");

        XMLPos pos = new XMLPos(doc);
        String filename = "";

         // Abfrage eines Attributwerts, beispielsweise von "font-filename"
        if (pos.go("PARAMS/FONT")) {
            filename = pos.get("font-filename");
            pos.back();
        }

         // Ausgabe des ermittelten Werts
        System.out.println("font filename: " + filename);

        assertEquals("Arial.ttf", filename); 
    }


    /**
     * Main function of Example2.
     * @param args unused command line arguments
     */
    public static void main(String[] args)
    {
        Example2 me = new Example2();

        try {
            me.testWrite();
            me.testRead();
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
}
