
//
// XML storage classes version 1.2
//
// WriterTest.java
//
// Copyright (c) 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs;

import java.io.IOException;

import org.junit.Test;

import de.mfuchs.xmlstorage.XMLInt;
import de.mfuchs.xmlstorage.stream.XMLStreamWriter;


/**
 * Example for using XMLStreamWriter.
 * 
 * @author martin
 */
public class WriterTest
{
	/**
	 * Write an example XML file to disk.
	 * @throws Exception
	 */
    @Test public void testWriter() throws IOException
    {
       XMLStreamWriter wr = new XMLStreamWriter("writertest.xml");

        wr.create("root");

          wr.create("example1");
            wr.create("PARAMS");
              wr.create("TEXT");
                wr.setContent("Testgruppe");
              wr.back(); // </TEXT>

              wr.create("COLOR");
                wr.create("RED");
                wr.setContent("234");
                wr.back(); // </RED>

                wr.create("GREEN");
                wr.setContent("22");
                wr.back(); // </GREEN>

                wr.create("BLUE");
                wr.setContent("33");
                wr.back(); // </BLUE>
              wr.back(); // </COLOR>

              wr.create("FONT");
                wr.create("FONT_FILENAME");
                wr.setContent("Arial.ttf");
                wr.back(); // </FONT_FILENAME>

                wr.create("SIZE");
                wr.setContent("12");
                wr.back(); // </SIZE>
              wr.back(); // </FONT>
            wr.back(); // </PARAMS>
          wr.back(); // </example1>

          wr.create("example2");
            wr.create("PARAMS");
              wr.put("text", "Testgruppe");

              wr.create("COLOR");
                wr.put("red", new XMLInt(234));
                wr.put("green", new XMLInt(22));
                wr.put("blue", new XMLInt(33));
              wr.back(); // </COLOR>

              wr.create("FONT");
                wr.put("font_filename", "Arial.ttf");
                wr.put("size", new XMLInt(12));
              wr.back(); // </FONT>
            wr.back(); // </PARAMS>
          wr.back(); // </example2>

          wr.create("example3");
            wr.create("Y_ACHSE");
              wr.put("Stopbits", new XMLInt(1));
              wr.put("Parity", "N");
            wr.back();
          wr.back(); // </example3>

        wr.back(); // </root>

        wr.close();
    }


    /**
     * Main function of WriterTest.
     * @param args unused command line arguments
     */
    public static void main(String[] args)
    {
        WriterTest me = new WriterTest();

        try {
            me.testWriter();
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
}
