
//
// XML storage classes version 1.2
//
// XMLBoolRef.java
//
// Copyright (c) 2004, 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage;


/**
 * XMLBoolRef is a type converter for boolean data with write access.
 */
public class XMLBoolRef
{
    public XMLBoolRef(XMLNode node, final String attrName)
	{
	    this(node, attrName, false);
	}

	public XMLBoolRef(XMLNode node, final String attrName, boolean def/*=false*/)
	{
	    _node = node;
	    _attrName = attrName;

	    if (node != null)
	        if (node.get(attrName).length() == 0)
	            assign(def);
	}

	/**
	 * @return boolean value of referenced node
	 */
	public boolean boolValue()
	{
	    if (_node != null)
	        return Boolean.valueOf(_node.get(_attrName)).booleanValue();
	    else
	        return false;
	}

	/**
	 * Set boolean value in referenced node.
	 * @param value
	 */
	public void assign(boolean value)
	{
	    if (_node != null)
	        _node.put(_attrName, String.valueOf(value));
   	}

	protected final XMLNode _node;
	protected final String _attrName;
}
