
//
// XML storage classes version 1.3
//
// XMLDoc.java
//
// Copyright (c) 2004, 2005, 2007, 2008 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;

import org.xml.sax.InputSource;


/**
 * XMLDoc works as XML document holder.
 */
public class XMLDoc extends XMLNode
{
	public XMLHeader _header = new XMLHeader();

    public XMLDoc()
	{
	    super("");
	}

	public XMLDoc(final String path) throws Exception
	{
		super("");

		readFile(path);
	}

	public void readFile(final String path) throws Exception
	{
	    InputStream in = new FileInputStream(path);

	    InputSource source = new InputSource(in);
	    source.setSystemId(path);

		read(source);
	}

	public void read(InputSource source) throws Exception
	{
		XMLDocReader reader = new XMLDocReader(this);

		reader.read(source);

		_header._additional = reader.getInstructions();
	}

	 /// write XML stream preserving previous white space and comments
	public void write(Writer out) throws Exception
	{
	    write(out, FORMAT_SMART);
	}

	 /// write XML stream
	 // FORMAT_SMART: preserving previous white space and comments
	public void write(Writer out, int mode/*=FORMAT_SMART*/) throws Exception
	{
		//TODO: use mode

		_header.print(out);

        if (_children.size() == 1)
            _children.getFirst().write(out);
        else if (!_children.isEmpty())
			throw new Exception("more than one XML root entry");
	}

	 /// write XML stream with formating
	public void writeFormating(Writer out) throws Exception
	{
		write(out, FORMAT_PRETTY);
	}

	public void writeFile(final String path) throws Exception
	{
	    writeFile(path, FORMAT_SMART);
	}

	public void writeFile(final String path, int mode/*=FORMAT_SMART*/) throws Exception
	{
	    String encoding = _header._encoding.length()>0? _header._encoding: "UTF-8";

	    Writer out = new OutputStreamWriter(new FileOutputStream(path), encoding);

	    try {
	        write(out, mode);
	    } finally {
		    out.close();
		}
	}

	public void writeFormating(final String path) throws Exception
	{
	    Writer out = new OutputStreamWriter(new FileOutputStream(path), "UTF-8");

	    try {
	        writeFormating(out);
	    } finally {
		    out.close();
		}
	}
}
