package de.mfuchs.xmlstorage;

import java.util.Iterator;

/**
 * XMLFilterIterator<T> is used by XMLChildrenFilter and XMLStreamFilter
 * to filter node iterations.
 * @author Martin Fuchs
 */
public final class XMLFilterIterator<T extends AbstractXMLNode> implements Iterator<T>
{
	public XMLFilterIterator(Iterator<T> it, final String filterName)
	{
  		_it = it;
		_filterName = filterName;

		_next = getNext();
		searchNext();
	}

    public boolean hasNext()
    {
        return _next != null;
    }

	public T next()
	{
	    T ret = _next;

	    if (_next != null) {
	        _next = getNext();
   			searchNext();
	    }

		return ret;
	}

	protected T getNext()
	{
	    if (_it.hasNext())
	        return _it.next();
	    else
	        return null;
	}

	private Iterator<T> _it;
    private T	_next;
    private String	_filterName;

	private void searchNext()
	{
   		while(_next!=null && !_next.getName().equals(_filterName))
   		    _next = getNext();
	}

    public void remove()
    {
        throw new UnsupportedOperationException("remove() not implemented for XMLFilterIterator");
    }
}
