
//
// XML storage classes version 1.2
//
// XMLHeader.java
//
// Copyright (c) 2004, 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage;

import java.io.IOException;
import java.io.Writer;


/**
 * XMLHeader manages the content of XML file headers.
 */
public class XMLHeader
{
    public XMLHeader()
	{
        this("1.0", "UTF-8", "");
	}

	public XMLHeader(final String xmlVersion/*="1.0"*/, final String encoding/*="UTF-8"*/, final String docType/*=""*/)
	{
		_version = xmlVersion;
		_encoding = encoding;
		_docType = docType;
		_additional = "";
	}

    public void print(Writer out) throws IOException
    {
        print(out, true);
    }

	public void print(Writer out, boolean pretty) throws IOException
	{
		out.write("<?xml version=\"");
		out.write(_version);
		out.write("\" encoding=\"");
		out.write(_encoding);
		out.write("\"?>");

        if (pretty)
            out.write('\n');

		if (_docType.length() > 0) {
		    out.write(_docType);
			out.write('\n');
		}

		if (_additional.length() > 0) {
		    out.write(_additional);
		    out.write('\n');
		}
	}

	public String	_version = "";
	public String	_encoding = "";
	public String	_docType = "";
	public String	_additional = "";
}
