
//
// XML storage classes version 1.2
//
// XMLHelper.java
//
// Copyright (c) 2004, 2005, 2007 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage;


/**
 * XMLHelpder converts XML string literals.
 */
public final class XMLHelper
{
	/**
	 * private constructor to disable instantiation.
	 */
	private XMLHelper()
	{
	}

    /**
     * Encode XML string literals.
     */
    public static String encodeXMLString(final String s)
    {
        return encodeXMLString(s, false);
    }

    /**
     * Encode XML string literals, optionally in CDATA sections.
     */
    public static String encodeXMLString(final String s, boolean cdata)
    {
    	StringBuffer buffer = new StringBuffer();

        if (cdata) {
            buffer.append("<![CDATA[");
            buffer.append(s);
            buffer.append("]]>");
        } else {
        	for(int i=0; i<s.length(); ++i) {
        	    char c = s.charAt(i);

        		switch(c) {
          		  case '<':
        		    buffer.append("&lt;");
        			break;

        		  case '>':
        		    buffer.append("&gt;");
        			break;

          		  case '&':
          		    buffer.append("&amp;");
          			break;

          		  case '"':
          		    buffer.append("&quot;");
          			break;

          		  case '\'':
        		    buffer.append("&apos;");
        			break;

        		  default:
        			buffer.append(c);
        		}
            }
    	}

    	return buffer.toString();
    }

    /**
     * Decode XML string literals.
     */
    public static String decodeXMLString(final String s)
    {
        StringBuffer buffer = new StringBuffer();

        for(int i=0; i<s.length(); ++i) {
            char c = s.charAt(i);

             // handle string literals
    		if (c == '&') {
    		    if (s.substring(i+1,i+4).equalsIgnoreCase("lt;")) {
					buffer.append('<');
					i += 3;
				} else if (s.substring(i+1,i+4).equalsIgnoreCase("gt;")) {
					buffer.append('>');
					i += 3;
    			} else if (s.substring(i+1,i+5).equalsIgnoreCase("amp;")) {
    				buffer.append('&');
    				i += 4;
				} else if (s.substring(i+1,i+6).equalsIgnoreCase("quot;")) {
    				buffer.append('"');
    				i += 5;
    			} else if (s.substring(i+1,i+6).equalsIgnoreCase("apos;")) {
    				buffer.append('\'');
    				i += 5;
    			} else
    				buffer.append(c);
    		}
             // handle CDATA sections
    		else if (c=='<' && s.regionMatches(i+1, "![CDATA[", 0, 8)) {
                int e = s.indexOf("]]>", i+9);
                if (e != -1) {
                    i += 9;
                    int l = e - i;
                    buffer.append(s.substring(i, i+l));
                    i += 3;
                } else
                    buffer.append(c);
            } else
    			buffer.append(c);
        }

    	return buffer.toString();
    }

	/// remove escape characters from the specified string
    public static String unescape(String s)
    {
        return XMLHelper.unescape(s, '"', '"');
    }

	/// remove escape characters from the specified string
    public static String unescape(String s, char b, char e)
    {
    //  if (s.charAt(0) == b)
    //      s = s.substring(1);
    //
    //  if (s.length()>0 && end[-1]==e)
    //      s = s.substring(0, s.length()-1);
    
        if (s.charAt(0) == b)
            if (s.length()>0 && s.charAt(s.length()-1)==e)
                s = s.substring(1, s.length()-1);
    
        return s;
    }
}
