
//
// XML storage classes version 1.2
//
// XMLInt.java
//
// Copyright (c) 2004, 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage;

import de.mfuchs.xmlstorage.stream.XMLStreamReader;


/**
 * XMLInt is a type converter for integer data.
 */
public class XMLInt
{
	public XMLInt(int value)
	{
		_value = value;
	}

	public XMLInt(final String value)
	{
	    this(value, 0);
	}

	public XMLInt(final String value, int def/*=0*/)
	{
		if (value!=null && value.length()>0)
			_value = Integer.parseInt(value);
		else
			_value = def;
	}


	public XMLInt(final AbstractXMLNode node, final String attrName)
	{
	    this(node, attrName, 0);
	}

	public XMLInt(final XMLPos pos, final String attrName)
	{
	    this(pos.cur(), attrName, 0);
	}

	public XMLInt(final XMLPos pos, final String attrName, int def/*=0*/)
	{
		this(pos.cur(), attrName, def);
	}

	public XMLInt(final XMLStreamReader reader, final String attrName)
	{
	    this(reader.getNode(), attrName, 0);
	}

	public XMLInt(final XMLStreamReader reader, final String attrName, int def/*=0*/)
	{
		this(reader.getNode(), attrName, def);
	}

	public XMLInt(final AbstractXMLNode node, final String attrName, int def/*=0*/)
	{
		final String value = node.get(attrName);

		if (value.length() > 0)
			_value = Integer.parseInt(value);
		else
			_value = def;
	}


	public int intValue()
	{
		return _value;
	}

	public String toString()
	{
		return String.valueOf(_value);
	}

	protected int _value;
}
