
//
// XML storage classes version 1.3
//
// XMLStreamNode.java
//
// Copyright (c) 2008 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage.stream;

import java.util.TreeMap;

import de.mfuchs.xmlstorage.AbstractXMLNode;
import de.mfuchs.xmlstorage.XMLHelper;


/**
 * XMLStreamNode is used to hold the data of the current XML Node in XMLStreamReader.
 */
public final class XMLStreamNode extends AbstractXMLNode
{
//	final private XMLStreamReader _reader;

	private String _name = "";
	private String _content = "";
	private TreeMap<String, String> _attributes = new TreeMap<String, String>();

	/**
	 * Empty XMLStreamNode default constructor.
	 */
	public XMLStreamNode(XMLStreamReader streamReader)
	{
//		_reader = streamReader;
	}

	public String getName()
	{
		return _name;
	}

    public String toString()
    {
        return _name;
    }

	protected void assign(String name)
	{
		_name = name;
		_content = "";
		_attributes.clear();
	}

	protected void setContent(String content)
    {
		_content = content;
    }

	protected void setAttributes(javax.xml.stream.XMLStreamReader reader)
    {
	    int attributes = reader.getAttributeCount();

	    for(int n=0; n<attributes; ++n) {
	    	final String attrNS = reader.getAttributeNamespace(n);
	    	final String attrName = reader.getAttributeLocalName(n);
	    	final String attrValue = reader.getAttributeValue(n);

	    	if (attrNS != null)
	    		_attributes.put(attrNS+":"+attrName, attrValue);
	    	else
	    		_attributes.put(attrName, attrValue);
	    }
    }

	 /// read only access to an attribute
	public String get(final String attrName)
	{
        String found = _attributes.get(attrName);

        if (found != null)
            return found;
        else
            return "";
	}

     /// read only access to an attribute with default value
    public String get(final String attrName, final String def)
    {
        String found = _attributes.get(attrName);

        if (found != null)
            return found;
        else
            return def;
    }

    /**
     * Return content data.
     */
	public String getContent()
	{
		return XMLHelper.decodeXMLString(_content);
	}
}
